@@ -1,6 +1,7 @@
 from django.contrib import admin
 
-from .models import ReceiverEmailConfiguration, SenderEmailConfiguration, EmailConfiguration
+from .models import ReceiverEmailConfiguration, SenderEmailConfiguration, \
+    EmailConfiguration
 
 
 @admin.register(ReceiverEmailConfiguration)
@@ -15,6 +16,9 @@ class SenderEmailConfigurationAdmin(admin.ModelAdmin):
 
 @admin.register(EmailConfiguration)
 class EmailConfigurationAdmin(admin.ModelAdmin):
-    list_display = ('SUBJECT',
-                    'HTML_File',
-                    'LOG_PATH',)
+    list_display = ('Subject',
+                    'Logo',
+                    'Banner',
+                    'Log_path',
+                    'Email_Content',
+                    'HTML_File',)
